---
name: Bug Report
about: Create a bug report to help us improve
title: "[BUG]: <your title here>"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behaviour.

**Expected behaviour**
A clear and concise description of what you expected to happen.

**Additional context**
Add any other context about the problem here, including any relevant system information and python version.
